lexicons\_builder.touch\_file package
=====================================

.. automodule:: lexicons_builder.touch_file
   :members:
   :undoc-members:
   :show-inheritance:

Submodules
----------

lexicons\_builder.touch\_file.touch\_file module
------------------------------------------------

.. automodule:: lexicons_builder.touch_file.touch_file
   :members:
   :undoc-members:
   :show-inheritance:
